.. _user_guide_building_pipeline_index:

Wrangling data with good defaults
=================================

This section covers how to build a predictive pipeline starting from a dataframe.
The skrub objects described in this section can be used as strong defaults for
building baseline pipelines, and can be customized for specific use cases.


.. toctree::
   :maxdepth: 3

   modules/default_wrangling/cleaning_dataframes
   modules/default_wrangling/table_vectorizer
   modules/default_wrangling/tabular_pipeline
